@@ -1,8 +1,8 @@
 #!/bin/sh
 
 #
-# DaVinci Resolve 16.1 Debian package creator
-# Release 2019-10-18
+# DaVinci Resolve 16.1.1 Debian package creator
+# Release 2019-10-31
 # By Daniel Tufvesson
 #
 
@@ -39,7 +39,7 @@ create_directory() {
 extract_tgz() {
     check_command tar
     if [ -f "$1" ] ; then
-	echo "[EXTRACT] $1 [TO] $2$3"
+	echo "[EXTRACT] $1 [TO] $2/$3"
 	tar -zxf "$1" -C "$2" $3
     else
 	echo "[ERROR: MISSING] $1"
@@ -57,7 +57,7 @@ make_executable() {
 }
 
 # Setup variables
-RESOLVE_VERSION=16.1
+RESOLVE_VERSION=16.1.1
 DEB_STEPPING=1
 case $1 in
     studio)
@@ -136,11 +136,11 @@ SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="066
 EOF
 
 # Install panel API library
-create_directory ${DEB_DIR}/usr/lib/
-extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib/ libDaVinciPanelAPI.so
+create_directory ${DEB_DIR}/usr/lib/x86_64-linux-gnu
+extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib/x86_64-linux-gnu libDaVinciPanelAPI.so
 
 # Create symlinks
-mkdir ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/
+create_directory ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/
 ln -s /opt/resolve/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/libBlackmagicRawAPI.so
 ln -s /opt/resolve/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/libBlackmagicRawAPI.so
 
@@ -179,14 +179,17 @@ chmod -R a+rw /opt/resolve/easyDCP
 chmod -R a+rw /opt/resolve/LUT
 chmod -R a+rw /opt/resolve/.license
 chmod -R a+rw /var/BlackmagicDesign/"DaVinci Resolve"
-test ! -e /usr/lib64_link_created_by_makeresolvedeb && test -e /usr/lib64 && echo Warning. /usr/lib64 already exist. If not properly setup ${RESOLVE_NAME} may not run correctly.
-test ! -e /usr/lib64 && ln -s /usr/lib/x86_64-linux-gnu/ /usr/lib64 && touch /usr/lib64_link_created_by_makeresolvedeb
+test ! -e /usr/lib64 && mkdir /usr/lib64 && touch /usr/lib64.by.makeresolvedeb
+test ! -h /usr/lib64/libcuda.so && ln -s /usr/lib/x86_64-linux-gnu/libcuda.so /usr/lib64/libcuda.so && touch /usr/lib64/libcuda.so.by.makeresolvedeb
+test ! -h /usr/lib64/libDaVinciPanelAPI.so && ln -s /usr/lib/x86_64-linux-gnu/libDaVinciPanelAPI.so /usr/lib64/libDaVinciPanelAPI.so
 exit 0
 EOF
 make_executable ${DEB_DIR}/DEBIAN/postinst
 cat > ${DEB_DIR}/DEBIAN/postrm <<EOF
 #!/bin/sh
-test -e /usr/lib64_link_created_by_makeresolvedeb && rm /usr/lib64 && rm /usr/lib64_link_created_by_makeresolvedeb
+test -h /usr/lib64/libDaVinciPanelAPI.so && rm /usr/lib64/libDaVinciPanelAPI.so
+test -e /usr/lib64/libcuda.so.by.makeresolvedeb && rm /usr/lib64/libcuda.so && rm /usr/lib64/libcuda.so.by.makeresolvedeb
+test -e /usr/lib64.by.makeresolvedeb && rmdir /usr/lib64 && rm /usr/lib64.by.makeresolvedeb
 exit 0
 EOF
 make_executable ${DEB_DIR}/DEBIAN/postrm
